@@ -2,7 +2,7 @@ getclf<-function(data, freq)
   {
     # Takes a sorted data frame and returns a likelihood function to be minimized
     nvars<-ncol(data)
-    pars<-double(1:(nvars*(nvars+3)/2))
+    pars<-double(nvars+nvars*(nvars+1)/2)
     testdata<-data[cumsum(freq),]
     presabs<-ifelse(is.na(testdata),0,1)
 
@@ -19,6 +19,6 @@ getclf<-function(data, freq)
 
     function(pars){
       .C("evallf",as.double(data),as.integer(nvars),as.integer(freq),
-         as.integer(length(freq)),as.integer(presabs),as.double(pars),val=double(1),PACKAGE="mvnmle")$val;
+         as.integer(x=length(freq)),as.integer(presabs),as.double(pars),val=double(1),PACKAGE="mvnmle")$val;
     }
   }
